<?php
  require_once __DIR__ . '/../../utils.php';
  require_once __DIR__ . '/../../inc/common.php';
  require_once __DIR__ . '/../../inc/constants.php';

  const NEED_TO_UPDATE = '<span class="note">NOTE: Please check <strong>Activate for all posts</strong> in order to regenerate hashes after you change that field</span>';
?>

  <div class="wrap" id="trinity-admin">
    <h1>Trinity Audio</h1>

    <?php
      trinity_audio_first_time_install_notice();
      if (!trinity_get_is_bulk_updated()) {
        trinity_show_warning_need_to_activate();
      }
    ?>

    <form action="options.php" method="post" onsubmit="trinityAudioOnSettingsFormSubmit(this)">
      <?php
        settings_errors();
        settings_fields('trinity_audio');
      ?>

      <h2>General configuration</h2>
      <table class="form-table">
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_SOURCE_LANGUAGE); ?>">
              Default language:
            </label>
          </th>
          <td><?php trinity_source_language(); ?></td>
        </tr>
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_GENDER_ID); ?>">
              Default gender:
            </label>
          </th>
          <td><?php trinity_source_gender(); ?></td>
        </tr>
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_SOURCE_NEW_POSTS_DEFAULT); ?>">
              New post default:
            </label>
          </th>
          <td><?php trinity_new_post_default(); ?></td>
        </tr>
      </table>

      <h2>Player settings</h2>
      <table class="form-table">
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_PLAYER_POSITION); ?>">
              Player position:
            </label>
          </th>
          <td><?php trinity_player_position(); ?></td>
        </tr>
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_PLAYER_LABEL); ?>">
              Player label:</label>
          </th>
          <td><?php trinity_player_label(); ?></td>
        </tr>
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_POWERED_BY); ?>">
              Display Powered by Trinity Audio:
            </label>
          </th>
          <td><?php trinity_display_powered_by(); ?></td>
        </tr>
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_PRECONNECT); ?>">
              Resource Preconnect:
            </label>
          </th>
          <td><?php trinity_preconnect(); ?></td>
        </tr>
      </table>

      <h2>Textual configuration</h2>
      <table class="form-table">
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_ADD_POST_TITLE); ?>">
              Add post title to audio:
            </label>
          </th>
          <td><?php trinity_add_post_title(); ?></td>
        </tr>
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_ADD_POST_EXCERPT); ?>">
              Add post excerpt to audio:
            </label>
          </th>
          <td><?php trinity_add_post_excerpt(); ?></td>
        </tr>
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_SKIP_TAGS); ?>">
              Skip HTML tags:
            </label>
          </th>
          <td><?php trinity_skip_tags(); ?></td>
        </tr>
        <tr>
          <th>
            <label for="<?php echo esc_attr(TRINITY_AUDIO_ALLOW_SHORTCODES); ?>">
              Allow shortcodes:
            </label>
          </th>
          <td><?php trinity_allow_shortcodes(); ?></td>
        </tr>
      </table>

      <!--      <div class="advanced">-->
      <!--        <h2>Advanced configuration</h2>-->
      <!--        <table class="form-table">-->
      <!--          <tr>-->
      <!--            <th>-->
      <!--              <label for="--><?//= TRINITY_AUDIO_CHECK_FOR_LOOP ?><!--">-->
      <!--                Check for <strong>in_the_loop()</strong>:-->
      <!--              </label>-->
      <!--            </th>-->
      <!--            <td>--><?php // trinity_check_for_loop() ?><!--</td>-->
      <!--          </tr>-->
      <!--        </table>-->
      <!--      </div>-->

      <table class="form-table">
        <tr>
          <th>
            <label for="trinity_audio_activate_for_all_posts">
              Activate for all posts:
            </label>
          </th>
          <td><?php trinity_activate_for_all_posts(); ?></td>
        </tr>
        <tr>
          <th style="padding: 0;">
            <button class="button button-primary">Save Changes
            </button>
          </th>
        </tr>
      </table>
    </form>
  </div>

<?php

  function trinity_source_language() {
    $languages = trinity_get_languages(); // keep here, is error is occur, it will display error via die().
    if (!$languages) {
      die(trinity_can_not_connect_error_message('Can\'t get list of supported languages.'));
    }

    echo "<select name='" . esc_attr(TRINITY_AUDIO_SOURCE_LANGUAGE) . "' id='" . esc_attr(TRINITY_AUDIO_SOURCE_LANGUAGE) . "'>";

    foreach ($languages as $lang) {
      $language_code = $lang->code;
      $language_name = $lang->name;

      $selected = trinity_get_source_language() === $language_code ? 'selected' : '';

      echo "<option value='" . esc_attr($language_code) . "' " . esc_attr($selected) . ">" . esc_html($language_name) . '</option>';
    }

    echo '</select>';

    echo '<p class="description">Use this to configure the default language that is used for your textual content in your site. In case you have more than one, please declare the main language used and use the individual post menu to define the language for it</p>';
  }

  function trinity_source_gender() {
    echo "<select name='" . esc_attr(TRINITY_AUDIO_GENDER_ID) . "' id='" . esc_attr(TRINITY_AUDIO_GENDER_ID) . "'>";

    foreach (TRINITY_AUDIO_GENDER_ARRAY as $key => $value) {
      $selected = trinity_get_gender() === $key ? 'selected' : '';

      echo "<option value='" . esc_attr($key) . "' " . esc_attr($selected) . '>' . esc_html($value) . '</option>';
    }

    echo '</select>';

    echo '<p class="description">Use this to choose the voice gender you prefer. You could also choose different gender per post in the post menu</p>';
  }

  function trinity_new_post_default() {
    $checked = trinity_get_new_posts_default() ? 'checked' : '';
    echo "<input type='checkbox' name='" . esc_attr(TRINITY_AUDIO_SOURCE_NEW_POSTS_DEFAULT) . "' id='" . esc_attr(TRINITY_AUDIO_SOURCE_NEW_POSTS_DEFAULT) . "' " . esc_attr($checked) . '>';

    echo '<p class="description">Check this inbox to make sure that each new post will have the Trinity Audio player enabled by default</p>';
  }

  function trinity_player_position() {
    echo "<select name='" . esc_attr(TRINITY_AUDIO_PLAYER_POSITION) . "' id='" . esc_attr(TRINITY_AUDIO_PLAYER_POSITION) . "'>";

    foreach (TRINITY_AUDIO_PLAYER_POSITION_ARRAY as $key => $value) {
      $selected = trinity_get_player_position() === $key ? 'selected' : '';

      echo "<option value='" . esc_attr($key) . "' " . esc_attr($selected) . '>' . esc_html($value) . '</option>';
    }

    echo '</select>';

    echo '<p class="description">Choose the position on the page you would like the player to appear on. We recommend placing it above the fold for best user experience</p>';
  }

  function trinity_player_label() {
    $value = trinity_get_player_label();
    echo "<input type='text' value='" . esc_attr($value) . "' name='" . esc_attr(TRINITY_AUDIO_PLAYER_LABEL) . "' id='" . esc_attr(TRINITY_AUDIO_PLAYER_LABEL) . "' class='regular-text'/>";
  }

  function trinity_display_powered_by() {
    $checked = trinity_get_powered_by() ? 'checked' : '';
    echo "<input type='checkbox' name='" . esc_attr(TRINITY_AUDIO_POWERED_BY) . "' id='" . esc_attr(TRINITY_AUDIO_POWERED_BY) . "' " . esc_attr($checked) . " value='1'>";

    echo '<p class="description">Select this option if you would like to give us credit and help other content creators reach out to us easily once they see the player on your site</p>';
  }

  function trinity_preconnect() {
    $checked = trinity_get_preconnect() ? 'checked' : '';
    echo "<input type='checkbox' name='" . esc_attr(TRINITY_AUDIO_PRECONNECT) . "' id='" . esc_attr(TRINITY_AUDIO_PRECONNECT) . "' " . esc_attr($checked) . " value='1'>";

    echo '<p class="description">This option let you to choose if you want to improve player loading speed by using preconnect</p>';
  }

  function trinity_add_post_title() {
    $checked = trinity_get_add_post_title() ? 'checked' : '';
    echo "<input type='checkbox' name='" . esc_attr(TRINITY_AUDIO_ADD_POST_TITLE) . "' id='" . esc_attr(TRINITY_AUDIO_ADD_POST_TITLE) . "' " . esc_attr($checked) . " value='1'>";

    echo '<p class="description">If enabled, each audio file will start by reading the post title. If not, the player will start reading from the main text</p>';
  }

  function trinity_add_post_excerpt() {
    $checked = trinity_get_add_post_excerpt() ? 'checked' : '';
    echo "<input type='checkbox' name='" . esc_attr(TRINITY_AUDIO_ADD_POST_EXCERPT) . "' id='" . esc_attr(TRINITY_AUDIO_ADD_POST_EXCERPT) . "' " . esc_attr($checked) . " value='1'>";

    echo '<p class="description">If enabled, each audio file will read an excerpt from the post at the beginning of the audio (after the title, if chosen). Please check this option only if you know what is actually written in the excerpt as it is usually not part of the viewable content to the publisher</p>';
  }

  function trinity_skip_tags() {
    $value = implode(',', trinity_get_skip_tags());

    echo "<input type='text' value='" . esc_attr($value) . "' name='" . esc_attr(TRINITY_AUDIO_SKIP_TAGS) . "' id='" . esc_attr(TRINITY_AUDIO_SKIP_TAGS) . "' class='regular-text'/>";

    echo '<p class="description">Enter HTML tags that should be ignored while reading a text, using comma delimiter, e.g. img, i, footer. <br/>' . NEED_TO_UPDATE . '</p>';
  }

  function trinity_allow_shortcodes() {
    $value = implode(',', trinity_get_allowed_shortcodes());

    echo "<input type='text' value='" . esc_attr($value) . "' name='" . esc_attr(TRINITY_AUDIO_ALLOW_SHORTCODES) . "' id='" . esc_attr(TRINITY_AUDIO_ALLOW_SHORTCODES) . "' class='regular-text'/>";

    echo '<p class="description">Enter shortcodes that should not be filtered out, using comma delimiter, e.g. gallery, myshortcode. By default all shortcodes are filtered out while reading text. <br/>' . NEED_TO_UPDATE . '</p>';
  }

  function trinity_check_for_loop() {
    $checked = trinity_get_check_for_loop() ? 'checked' : '';
    echo "<input type='checkbox' name='" . esc_attr(TRINITY_AUDIO_CHECK_FOR_LOOP) . "' id='" . esc_attr(TRINITY_AUDIO_CHECK_FOR_LOOP) . "' " . esc_attr($checked) . " value='1'>";

    echo '<p class="description">Render player if <strong>in_the_loop()</strong> is true. Can help publishers, using posts injected by other services in not standard WordPress way</p>';
  }

  function trinity_activate_for_all_posts() {
    $is_checked = !!trinity_get_is_bulk_updated();
    $checked    = $is_checked ? '' : 'checked';
    $disabled   = $checked ? 'disabled=disabled' : '';

    echo "<div>
            <input type='checkbox' name='trinity_audio_activate_for_all_posts' id='trinity_audio_activate_for_all_posts' " . esc_attr($checked) . ' ' . esc_attr($disabled) . " value='1'>
            <span class='trinity-status-wrapper'>
              <span class='status error'>
                  <span class='dashicons dashicons-dismiss'
                        style='color: red'></span>
                  <span>A problem occurred while activating. Please try again later</span>
              </span>
              <span class='status progress'>
                  <span class='dashicons dashicons-update'></span>
                  <span class='description'></span>
              </span>
            </span>
          </div>
         ";
  }

  function trinity_show_warning_need_to_activate() {
    echo '
        <div class="notice notice-warning activate-plugin">
          <p class="message">Your Trinity Audio player is not functional yet! Please review the settings and click <strong>Save Changes</strong> at the bottom of the page to activate it.</p>
          <p><a href="https://trinityaudio.ai/the-trinity-audio-wordpress-plugin-implementation-guide/" target="_blank">Click here for further details</a></p>
        </div>
    ';
  }

  function trinity_audio_first_time_install_notice() {
    if (trinity_get_first_time_install()) {
      ?>
      <div class="notice notice-info">
        <p>We're excited that you've decided to join the audio future! Please note that our servers might take up to 5
          minutes to update before you can start using the plugin. Almost there!</p>
          <p>
              Please save your secret recovery key <b> (Install Key): <?php echo trinity_get_install_key(); ?> </b> in a safe place.
              This key is unique and bound to your domain. It is required for restoring your installation (a new environment of any sort).
          </p>
      </div>
      <?php
    }
  }
